@@ -303,15 +303,15 @@ class LiveMarketMonitor:
         return table
     
     def run_live_monitor(self):
-        """Run the live monitoring loop with proper cleanup"""
+        """Run the live monitoring loop with log-style output"""
         self.console.print(Panel(
             "[bold red]🔴 LIVE MARKET MONITOR STARTED[/bold red]\n"
             "[dim]Press Ctrl+C to stop monitoring[/dim]",
             style="red"
         ))
-        
+
         self._running = True
-        
+
         try:
             # Initial data fetch to test
             initial_data = self.get_market_data()
@@ -319,25 +319,46 @@ class LiveMarketMonitor:
                 self.console.print(f"[red]❌ No data found for category: {self.category}[/red]")
                 self.console.print("[yellow]This might be due to API issues or no active markets[/yellow]")
                 return
-            
+
             self.console.print(f"[green]✅ Found {len(initial_data)} markets to monitor[/green]")
-            
-            # Use Live display with proper cleanup
-            with Live(self.generate_live_table(), refresh_per_second=4, console=self.console) as live:
-                self._live_display = live
-                while self._running:
-                    try:
-                        live.update(self.generate_live_table())
-                        time.sleep(0.25)  # Update every 250ms for smoother live updates
-                    except Exception as e:
-                        if self._running:  # Only log errors if we're still supposed to be running
-                            self.console.print(f"[red]Update error: {e}[/red]")
-                        time.sleep(1)  # Wait a bit before retrying
-        
+            self.console.print(f"[cyan]📊 Monitoring {len(initial_data)} markets in real-time...[/cyan]")
+            self.console.print("=" * 80)
+
+            # Log-style live output
+            last_update = {}
+            while self._running:
+                try:
+                    markets = self.get_market_data()
+                    current_time = datetime.now(timezone.utc).strftime("%H:%M:%S")
+
+                    for market in markets:
+                        market_id = market.get("id")
+                        if market_id not in last_update:
+                            # First time seeing this market
+                            self._print_market_update(market, current_time, "NEW")
+                            last_update[market_id] = self._get_market_values(market)
+                        else:
+                            # Check for changes
+                            old_values = last_update[market_id]
+                            new_values = self._get_market_values(market)
+
+                            if new_values != old_values:
+                                # Market has changed
+                                direction = self._get_change_direction(old_values, new_values)
+                                self._print_market_update(market, current_time, direction)
+                                last_update[market_id] = new_values
+
+                    time.sleep(1)  # Update every second for log-style output
+
+                except Exception as e:
+                    if self._running:  # Only log errors if we're still supposed to be running
+                        self.console.print(f"[red]{datetime.now(timezone.utc).strftime('%H:%M:%S')} | ERROR: {e}[/red]")
+                    time.sleep(2)  # Wait longer on errors
+
         except KeyboardInterrupt:
-            self.console.print("\n[yellow]🔴 Live monitoring stopped by user[/yellow]")
+            self.console.print(f"\n[yellow]{datetime.now(timezone.utc).strftime('%H:%M:%S')} | 🔴 Live monitoring stopped by user[/yellow]")
         except Exception as e:
-            self.console.print(f"\n[red]🔴 Live monitoring error: {e}[/red]")
+            self.console.print(f"\n[red]{datetime.now(timezone.utc).strftime('%H:%M:%S')} | 🔴 Live monitoring error: {e}[/red]")
         finally:
             self._running = False
             self.cleanup()
@@ -347,15 +368,15 @@ class LiveMarketMonitor:
         try:
             # Stop the running flag
             self._running = False
-            
+
             # Clear the live display
             if self._live_display:
                 self._live_display.stop()
                 self._live_display = None
-            
+
             # Clear console output
             self.console.clear()
-            
+
             # Close API clients
             if hasattr(self.gamma_client, 'close'):
                 self.gamma_client.close()
@@ -363,26 +384,124 @@ class LiveMarketMonitor:
                 self.clob_client.close()
             if hasattr(self.subgraph_client, 'close'):
                 self.subgraph_client.close()
-            
+
             # Clear state data
             self.previous_data.clear()
             self.price_history.clear()
             self.volume_history.clear()
-            
+
+            # Clean up temporary script file
+            script_path = "/tmp/polyterm_live_monitor.py"
+            try:
+                if os.path.exists(script_path):
+                    os.remove(script_path)
+            except:
+                pass
+
             # Force garbage collection
             import gc
             gc.collect()
-            
+
         except Exception as e:
             # Don't let cleanup errors prevent termination
             pass
-        
+
         # Force exit to ensure complete termination
         try:
             os._exit(0)
         except:
             sys.exit(0)
 
+    def _get_market_values(self, market):
+        """Get comparable values from market data"""
+        try:
+            # Get title
+            title = ""
+            if market.get('markets') and len(market.get('markets', [])) > 0:
+                title = market['markets'][0].get('question', market.get('title', ''))
+            else:
+                title = market.get('title', '')
+
+            # Get price and volume
+            price = 0
+            if market.get('markets') and len(market.get('markets', [])) > 0:
+                outcome_prices = market['markets'][0].get('outcomePrices')
+                if isinstance(outcome_prices, str):
+                    import json
+                    try:
+                        outcome_prices = json.loads(outcome_prices)
+                    except:
+                        outcome_prices = None
+                if outcome_prices and isinstance(outcome_prices, list) and len(outcome_prices) > 0:
+                    price = float(outcome_prices[0])
+
+            volume = float(market.get('volume24hr', 0) or 0)
+
+            return {
+                'title': title[:30],  # Truncate for display
+                'price': price,
+                'volume': volume
+            }
+        except Exception:
+            return {'title': 'Unknown', 'price': 0, 'volume': 0}
+
+    def _get_change_direction(self, old_values, new_values):
+        """Determine if price/volume changed up or down"""
+        try:
+            if new_values['price'] > old_values['price']:
+                return "↗ UP"
+            elif new_values['price'] < old_values['price']:
+                return "↘ DOWN"
+            elif new_values['volume'] > old_values['volume']:
+                return "📊 VOL+"
+            else:
+                return "→ SAME"
+        except:
+            return "→ CHG"
+
+    def _print_market_update(self, market, timestamp, direction):
+        """Print a single market update in log format"""
+        try:
+            values = self._get_market_values(market)
+
+            # Format price and volume
+            price_str = ".4f" if values['price'] < 1 else ".2f"
+            price_display = f"${values['price']:{price_str}}"
+
+            volume_display = ".0f"
+            if values['volume'] < 1000:
+                volume_display = ".0f"
+            elif values['volume'] < 1000000:
+                volume_display = ".0f"
+                values['volume'] /= 1000
+                volume_display += "K"
+            else:
+                volume_display = ".1f"
+                values['volume'] /= 1000000
+                volume_display += "M"
+
+            if volume_display.endswith("K"):
+                volume_str = f"${values['volume']:{volume_display}}K"
+            elif volume_display.endswith("M"):
+                volume_str = f"${values['volume']:{volume_display}}M"
+            else:
+                volume_str = f"${values['volume']:{volume_display}}"
+
+            # Color code based on direction
+            if "UP" in direction:
+                color = "green"
+            elif "DOWN" in direction:
+                color = "red"
+            elif "VOL+" in direction:
+                color = "yellow"
+            else:
+                color = "blue"
+
+            self.console.print(f"[{color}]{timestamp} | {values['title'][:25]:<25} | {price_display:>8} | {volume_str:>8} | {direction}[/{color}]")
+
+        except Exception as e:
+            self.console.print(f"[red]{timestamp} | ERROR formatting market: {e}[/red]")
+
 
 @click.command()
 @click.option("--market", help="Market ID or slug to monitor")
@@ -500,10 +619,10 @@ monitor.run_live_monitor()
         
         # Launch in new terminal
         if sys.platform == "darwin":  # macOS
-            subprocess.Popen([
-                "osascript", "-e", 
-                f'tell app "Terminal" to do script "python3 {script_path}"'
-            ])
+            subprocess.run([
+                "osascript", "-e",
+                f'tell app "Terminal" to do script "{sys.executable} {script_path}"'
+            ], timeout=10)
         elif sys.platform.startswith("linux"):  # Linux
             subprocess.Popen([
                 "gnome-terminal", "--", "python3", script_path
