@@ -43,6 +43,55 @@ class MainMenu:
         
         return "", ""
     
+    def quick_update(self) -> bool:
+        """Perform a quick update from the main menu
+        
+        Returns:
+            True if update was successful, False otherwise
+        """
+        try:
+            import subprocess
+            import sys
+            import importlib
+            
+            self.console.print("\n[bold green]🔄 Quick Update Starting...[/bold green]")
+            
+            # Check for pipx first (preferred)
+            try:
+                subprocess.run(["pipx", "--version"], capture_output=True, check=True)
+                update_cmd = ["pipx", "upgrade", "polyterm"]
+                method = "pipx"
+            except (subprocess.CalledProcessError, FileNotFoundError):
+                # Fallback to pip
+                update_cmd = [sys.executable, "-m", "pip", "install", "--upgrade", "polyterm"]
+                method = "pip"
+            
+            self.console.print(f"[dim]Using {method} to update...[/dim]")
+            
+            # Run update
+            result = subprocess.run(update_cmd, capture_output=True, text=True)
+            
+            if result.returncode == 0:
+                # Force reload to get new version
+                importlib.reload(polyterm)
+                new_version = polyterm.__version__
+                
+                self.console.print(f"[bold green]✅ Update successful![/bold green]")
+                self.console.print(f"[green]Updated to version {new_version}[/green]")
+                self.console.print()
+                self.console.print("[bold yellow]🔄 Restart Required[/bold yellow]")
+                self.console.print("[yellow]Please restart PolyTerm to use the new version.[/yellow]")
+                return True
+            else:
+                self.console.print("[bold red]❌ Update failed[/bold red]")
+                if result.stderr:
+                    self.console.print(f"[red]Error: {result.stderr}[/red]")
+                return False
+                
+        except Exception as e:
+            self.console.print(f"[bold red]❌ Update error: {e}[/bold red]")
+            return False
+    
     def display(self):
         """Display main menu with all options, responsive to terminal width"""
         # Get terminal width, fallback to 80 if not available
