@@ -192,35 +192,64 @@ monitor = LiveMarketMonitor(config, market_id="{market_id or ''}", category="{ca
 monitor.run_live_monitor()
 '''
     
-    # Write temporary script
+    # Write temporary script with proper synchronization
     script_path = "/tmp/polyterm_live_monitor.py"
+
+    # Create script with forced disk sync
     with open(script_path, 'w') as f:
         f.write(script_content)
-    
+        f.flush()  # Force write to buffer
+        os.fsync(f.fileno())  # Force write to disk
+
     # Make script executable
     os.chmod(script_path, 0o755)
-    
+
+    # Verify script exists and is readable
+    if not os.path.exists(script_path):
+        console.print("[red]❌ Failed to create script file[/red]")
+        return
+
+    # Read back to verify content
     try:
-        # Launch in new terminal based on platform
+        with open(script_path, 'r') as f:
+            if len(f.read()) != len(script_content):
+                console.print("[red]❌ Script file incomplete[/red]")
+                return
+    except:
+        console.print("[red]❌ Cannot read script file[/red]")
+        return
+
+    console.print(f"[green]✅ Script created at {script_path}[/green]")
+
+    try:
+        # Launch in new terminal with blocking call to ensure it starts
         if sys.platform == "darwin":  # macOS
-            subprocess.Popen([
-                "osascript", "-e", 
-                f'tell app "Terminal" to do script "python3 {script_path}"'
-            ])
+            # Use subprocess.run instead of Popen for synchronous execution
+            # Use sys.executable to ensure we use the same Python that has polyterm installed
+            result = subprocess.run([
+                "osascript", "-e",
+                f'tell app "Terminal" to do script "{sys.executable} {script_path}"'
+            ], capture_output=True, text=True, timeout=10)
+
+            if result.returncode == 0:
+                console.print("[green]✅ Second terminal launched successfully[/green]")
+            else:
+                console.print(f"[red]❌ Terminal launch failed: {result.stderr}[/red]")
+
         elif sys.platform.startswith("linux"):  # Linux
-            subprocess.Popen([
+            subprocess.run([
                 "gnome-terminal", "--", "python3", script_path
-            ])
+            ], timeout=5)
         elif sys.platform == "win32":  # Windows
-            subprocess.Popen([
+            subprocess.run([
                 "start", "cmd", "/k", f"python {script_path}"
-            ])
+            ], shell=True, timeout=5)
         else:
             # Fallback - run in current terminal
             console.print("[yellow]Running live monitor in current terminal...[/yellow]")
             console.print("[dim]Press Ctrl+C to stop[/dim]")
             console.print()
-            
+
             # Import and run directly
             from polyterm.cli.commands.live_monitor import LiveMarketMonitor
             from polyterm.utils.config import Config
@@ -254,10 +283,5 @@ monitor.run_live_monitor()
         except Exception as fallback_error:
             console.print(f"[red]Error running live monitor: {fallback_error}[/red]")
     
-    finally:
-        # Clean up temporary script
-        try:
-            if os.path.exists(script_path):
-                os.remove(script_path)
-        except:
-            pass
+    # Note: Script cleanup is handled by the live monitor itself when it exits
+    # This prevents premature deletion before the second terminal can execute it
