@@ -116,6 +116,8 @@ def update_polyterm(console: RichConsole):
     
     console.print(Panel("[bold green]🔄 PolyTerm Update[/bold green]", style="green"))
     console.print()
+    console.print("[dim]This will automatically update PolyTerm to the latest version.[/dim]")
+    console.print()
     
     import subprocess
     import sys
@@ -183,7 +185,15 @@ def update_polyterm(console: RichConsole):
             console.print("[bold red]❌ No update method available[/bold red]")
             console.print("[red]Neither pipx nor pip could be found.[/red]")
             console.print()
-            console.print("[yellow]Please install Python package manager manually.[/yellow]")
+            console.print("[yellow]📋 Manual Update Instructions:[/yellow]")
+            console.print()
+            console.print("[dim]1. Open a new terminal window[/dim]")
+            console.print("[dim]2. Run one of these commands:[/dim]")
+            console.print("[dim]   • pipx upgrade polyterm[/dim]")
+            console.print("[dim]   • pip install --upgrade polyterm[/dim]")
+            console.print("[dim]3. Restart PolyTerm[/dim]")
+            console.print()
+            console.print("[yellow]💡 Need help? Visit: https://github.com/NYTEMODEONLY/polyterm[/yellow]")
             return
         
         # Step 4: Perform update
@@ -217,10 +227,16 @@ def update_polyterm(console: RichConsole):
                     console.print("[green]✅ Update completed successfully![/green]")
                 
                 console.print()
-                console.print("[bold yellow]🔄 Restart Required[/bold yellow]")
-                console.print("[yellow]Please restart PolyTerm to use the new version.[/yellow]")
+                console.print("[bold green]🎉 Update Complete![/bold green]")
                 console.print()
-                console.print("[dim]New features may be available![/dim]")
+                console.print("[bold yellow]🔄 Next Steps:[/bold yellow]")
+                console.print("[yellow]1. Close this PolyTerm window[/yellow]")
+                console.print("[yellow]2. Open a new terminal[/yellow]")
+                console.print("[yellow]3. Run: polyterm[/yellow]")
+                console.print()
+                console.print("[green]✨ New features and improvements are now available![/green]")
+                console.print()
+                console.print("[dim]Press Enter to continue (you can still use current session)[/dim]")
                 
             except Exception as e:
                 console.print("[green]✅ Update completed![/green]")
